@@ -11,6 +11,8 @@
 #include <QGuiApplication>
 #else
 #include <QApplication>
+
+#include <KCrash>
 #endif
 
 #include "calendarcontroller.h"
@@ -22,9 +24,14 @@
 #include "localcalendar.h"
 #include "settingscontroller.h"
 #include "version.h"
+
 #include <KAboutData>
 #include <KLocalizedContext>
 #include <KLocalizedString>
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
+
 #include <QCommandLineParser>
 #include <QIcon>
 #include <QNetworkAccessManager>
@@ -40,7 +47,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #ifdef Q_OS_ANDROID
     QGuiApplication app{argc, argv};
     QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+#if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
     KColorSchemeManager colorMgr; // enables automatic dark mode handling
+#else
+    (void)KColorSchemeManager::instance(); // enables automatic dark mode handling
+#endif
 #else
     QApplication app{argc, argv};
     // Default to org.kde.desktop style unless the user forces another style
@@ -63,6 +74,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     KAboutData::setApplicationData(about);
 
+#ifndef Q_OS_ANDROID
+    KCrash::initialize();
+#endif
+
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
     parser.process(app);
@@ -99,7 +114,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonInstance<EventController>("org.kde.kongress", 0, 1, "EventController", &eventController);
 
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextObject(new KLocalizedContext{&engine});
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+#else
+    engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
+#endif
     engine.loadFromModule("org.kde.kongress", "Main");
 
     if (engine.rootObjects().isEmpty()) {
